@@ -114,6 +114,16 @@ static inline __m256i letter_mask(__m256i x) {
 }
 #endif
 
+#ifdef __ARM_NEON
+static inline int8x16_t letter_mask(int8x16_t x) {
+#ifdef SEQ_MASK
+	return vandq_s8(x, vdupq_n_s8(LETTER_MASK));
+#else
+	return x;
+#endif
+}
+#endif
+
 extern const ValueTraits amino_acid_traits;
 extern const ValueTraits nucleotide_traits;
 extern ValueTraits value_traits;
@@ -163,4 +173,4 @@ using DictId = int64_t;
 using Score = int32_t;
 using TaxId = int32_t;
 using CentroidId = OId;
-using SuperBlockId = int32_t;
\ No newline at end of file
+using SuperBlockId = int32_t;
