@@ -31,8 +31,21 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "taxonomy_nodes.h"
 #include "../util/data_structures/bit_vector.h"
 
-std::string get_accession(const std::string &t);
-std::vector<std::string> accession_from_title(const char *title);
+struct AccessionParsing {
+	AccessionParsing():
+		uniref_prefix(0),
+		gi_prefix(0),
+		prefix_before_pipe(0),
+		suffix_after_pipe(0),
+		suffix_after_dot(0),
+		pdb_suffix(0)
+	{}
+	friend std::ostream& operator<<(std::ostream& s, const AccessionParsing& stat);
+	int64_t uniref_prefix, gi_prefix, prefix_before_pipe, suffix_after_pipe, suffix_after_dot, pdb_suffix;
+};
+
+std::string get_accession(const std::string &t, AccessionParsing& stat);
+std::vector<std::string> accession_from_title(const char *title, AccessionParsing& stat);
 
 struct Taxonomy
 {
