@@ -65,7 +65,8 @@ Hsp traceback(_cbs bias_correction, const Matrix<Cell>& dp, const DpTarget& targ
 	out.matrix = target.matrix;
 	assign_stats(out, stats);
 	out.query_source_range = TranslatedPosition::absolute_interval(TranslatedPosition(out.query_range.begin_, p.frame), TranslatedPosition(out.query_range.end_, p.frame), p.query_source_len);
-	return out;
+    out.subject_source_range = out.subject_range;
+    return out;
 }
 
 template<typename _sv, typename _cbs>
@@ -117,7 +118,8 @@ Hsp traceback(_cbs bias_correction, const TracebackVectorMatrix<_sv> &dp, const
 	out.transcript.reverse();
 	out.transcript.push_terminator();
 	out.query_source_range = TranslatedPosition::absolute_interval(TranslatedPosition(out.query_range.begin_, p.frame), TranslatedPosition(out.query_range.end_, p.frame), p.query_source_len);
-	out.approx_id = out.approx_id_percent(p.query, target.seq);
+    out.subject_source_range = out.subject_range;
+    out.approx_id = out.approx_id_percent(p.query, target.seq);
 	return out;
 }
 
