@@ -68,16 +68,24 @@ cigar_t* cigar_new(
   cigar->begin_offset = 0;
   cigar->end_offset = 0;
   cigar->score = INT32_MIN;
+  cigar->end_v = -1;
+  cigar->end_h = -1;
   // CIGAR
+  cigar->cigar_length = 0;
   cigar->cigar_buffer = calloc(max_operations,sizeof(uint32_t));
   // Return
   return cigar;
 }
 void cigar_clear(
     cigar_t* const cigar) {
+  // Alignment operations
   cigar->begin_offset = 0;
   cigar->end_offset = 0;
+  // Score and end position
   cigar->score = INT32_MIN;
+  cigar->end_v = -1;
+  cigar->end_h = -1;
+  // CIGAR
   cigar->cigar_length = 0;
 }
 void cigar_resize(
@@ -114,17 +122,35 @@ int cigar_count_matches(
   }
   return num_matches;
 }
-void cigar_append(
+void cigar_append_forward(
     cigar_t* const cigar_dst,
     cigar_t* const cigar_src) {
-  // Append
+  // Parameters
   const int cigar_length = cigar_src->end_offset - cigar_src->begin_offset;
   char* const operations_src = cigar_src->operations + cigar_src->begin_offset;
   char* const operations_dst = cigar_dst->operations + cigar_dst->end_offset;
+  // Append forward
   memcpy(operations_dst,operations_src,cigar_length);
   // Update offset
   cigar_dst->end_offset += cigar_length;
 }
+void cigar_append_reverse(
+    cigar_t* const cigar_dst,
+    cigar_t* const cigar_src) {
+  // Parameters
+  const int begin_offset = cigar_src->begin_offset;
+  const int end_offset = cigar_src->end_offset;
+  const int cigar_length = end_offset - begin_offset;
+  char* const operations_src = cigar_src->operations + begin_offset;
+  char* const operations_dst = cigar_dst->operations + cigar_dst->end_offset;
+  // Append reverse
+  int i;
+  for (i=0;i<cigar_length;++i) {
+    operations_dst[i] = operations_src[cigar_length-1-i];
+  }
+  // Update offset
+  cigar_dst->end_offset += cigar_length;
+}
 void cigar_append_deletion(
     cigar_t* const cigar,
     const int length) {
@@ -275,7 +301,7 @@ int cigar_score_gap_affine(
   }
   return score;
 }
-int cigar_score_gap_affine2p_get_operations_score(
+int cigar_score_gap_affine2p_score_op(
     const char operation,
     const int length,
     affine2p_penalties_t* const penalties) {
@@ -304,14 +330,14 @@ int cigar_score_gap_affine2p(
   for (i=cigar->begin_offset;i<cigar->end_offset;++i) {
     // Account for operation
     if (cigar->operations[i] != last_op && last_op != '\0') {
-      score -= cigar_score_gap_affine2p_get_operations_score(last_op,op_length,penalties);
+      score -= cigar_score_gap_affine2p_score_op(last_op,op_length,penalties);
       op_length = 0;
     }
     last_op = cigar->operations[i];
     ++op_length;
   }
   // Account for last operation
-  score -= cigar_score_gap_affine2p_get_operations_score(last_op,op_length,penalties);
+  score -= cigar_score_gap_affine2p_score_op(last_op,op_length,penalties);
   return score;
 }
 /*
@@ -348,9 +374,9 @@ void cigar_copy(
          cigar_src->end_offset-cigar_src->begin_offset);
 }
 void cigar_discover_mismatches(
-    char* const pattern,
+    const char* const pattern,
     const int pattern_length,
-    char* const text,
+    const char* const text,
     const int text_length,
     cigar_t* const cigar) {
   // Refine adding mismatches
@@ -390,62 +416,91 @@ void cigar_discover_mismatches(
  *   the beginning, under a given distance function
  *
  */
-void cigar_maxtrim_gap_linear(
+bool cigar_maxtrim_gap_linear(
     cigar_t* const cigar,
     linear_penalties_t* const penalties) {
   // Parameters
   const char* const operations = cigar->operations;
   const int begin_offset = cigar->begin_offset;
   const int end_offset = cigar->end_offset;
+  const int match_score = (penalties->match!=0) ? penalties->match : -1;
   // Max-score
-  int max_score = 0, max_score_offset = begin_offset;
+  int max_score = 0, max_score_offset = begin_offset, max_end_v = 0, max_end_h = 0;
   // Traverse all cigar
-  int score = 0, i;
+  int score = 0, end_v = 0, end_h = 0, i;
   for (i=begin_offset;i<end_offset;++i) {
     // Update score
     switch (operations[i]) {
-      case 'M': score -= penalties->match; break;
-      case 'X': score -= penalties->mismatch; break;
-      case 'I': score -= penalties->indel; break;
-      case 'D': score -= penalties->indel; break;
+      case 'M':
+        score -= match_score;
+        ++end_v; ++end_h;
+        break;
+      case 'X':
+        score -= penalties->mismatch;
+        ++end_v; ++end_h;
+        break;
+      case 'I':
+        score -= penalties->indel;
+        ++end_h;
+        break;
+      case 'D':
+        score -= penalties->indel;
+        ++end_v;
+        break;
     }
     // Compare max
     if (max_score < score) {
       max_score = score;
       max_score_offset = i;
+      max_end_v = end_v;
+      max_end_h = end_h;
     }
   }
   // Keep the max-scoring part of the cigar
-  cigar->operations[max_score_offset+1] = '\0';
-  cigar->end_offset = max_score_offset + 1;
-  cigar->score = score;
+  const bool cigar_trimmed = (max_score_offset != end_offset-1);
+  if (max_score == 0) {
+    cigar_clear(cigar);
+  } else {
+    cigar->operations[max_score_offset+1] = '\0';
+    cigar->end_offset = max_score_offset + 1;
+    cigar->score = max_score;
+    cigar->end_v = max_end_v;
+    cigar->end_h = max_end_h;
+  }
+  // Return
+  return cigar_trimmed;
 }
-void cigar_maxtrim_gap_affine(
+bool cigar_maxtrim_gap_affine(
     cigar_t* const cigar,
     affine_penalties_t* const penalties) {
   // Parameters
   const char* const operations = cigar->operations;
   const int begin_offset = cigar->begin_offset;
   const int end_offset = cigar->end_offset;
+  const int match_score = (penalties->match!=0) ? penalties->match : -1;
   // Max-score
-  int max_score = 0, max_score_offset = begin_offset;
+  int max_score = 0, max_score_offset = begin_offset, max_end_v = 0, max_end_h = 0;
   // Traverse all cigar
   char last_op = '\0';
-  int score = 0, i;
+  int score = 0, end_v = 0, end_h = 0, i;
   for (i=begin_offset;i<end_offset;++i) {
     // Update score
     switch (operations[i]) {
       case 'M':
-        score -= penalties->match;
+        score -= match_score;
+        ++end_v; ++end_h;
         break;
       case 'X':
         score -= penalties->mismatch;
-        break;
-      case 'D':
-        score -= penalties->gap_extension + ((last_op=='D') ? 0 : penalties->gap_opening);
+        ++end_v; ++end_h;
         break;
       case 'I':
         score -= penalties->gap_extension + ((last_op=='I') ? 0 : penalties->gap_opening);
+        ++end_h;
+        break;
+      case 'D':
+        score -= penalties->gap_extension + ((last_op=='D') ? 0 : penalties->gap_opening);
+        ++end_v;
         break;
     }
     last_op = operations[i];
@@ -453,50 +508,108 @@ void cigar_maxtrim_gap_affine(
     if (max_score < score) {
       max_score = score;
       max_score_offset = i;
+      max_end_v = end_v;
+      max_end_h = end_h;
     }
   }
   // Keep the max-scoring part of the cigar
-  cigar->operations[max_score_offset+1] = '\0';
-  cigar->end_offset = max_score_offset + 1;
-  cigar->score = score;
+  const bool cigar_trimmed = (max_score_offset != end_offset-1);
+  if (max_score == 0) {
+    cigar_clear(cigar);
+  } else {
+    cigar->operations[max_score_offset+1] = '\0';
+    cigar->end_offset = max_score_offset + 1;
+    cigar->score = max_score;
+    cigar->end_v = max_end_v;
+    cigar->end_h = max_end_h;
+  }
+  // Return
+  return cigar_trimmed;
 }
-void cigar_maxtrim_gap_affine2p(
+int cigar_maxtrim_gap_affine2p_score_op(
+    const char operation,
+    const int length,
+    affine2p_penalties_t* const penalties,
+    int* const end_v,
+    int* const end_h) {
+  switch (operation) {
+    case 'M': {
+      *end_v += length; *end_h += length;
+      const int match_score = (penalties->match!=0) ? penalties->match : -1;
+      return match_score*length;
+    }
+    case 'X':
+      *end_v += length; *end_h += length;
+      return penalties->mismatch*length;
+    case 'D': {
+      *end_v += length;
+      const int score1 = penalties->gap_opening1 + penalties->gap_extension1*length;
+      const int score2 = penalties->gap_opening2 + penalties->gap_extension2*length;
+      return MIN(score1,score2);
+    }
+    case 'I': {
+      *end_h += length;
+      const int score1 = penalties->gap_opening1 + penalties->gap_extension1*length;
+      const int score2 = penalties->gap_opening2 + penalties->gap_extension2*length;
+      return MIN(score1,score2);
+    }
+    default:
+      fprintf(stderr,"[CIGAR] Computing CIGAR score: Unknown operation\n");
+      exit(1);
+  }
+}
+bool cigar_maxtrim_gap_affine2p(
     cigar_t* const cigar,
     affine2p_penalties_t* const penalties) {
   // Parameters
   const char* const operations = cigar->operations;
   const int begin_offset = cigar->begin_offset;
   const int end_offset = cigar->end_offset;
+  if (begin_offset >= end_offset) return false;
   // Max-score
-  int max_score = 0, max_score_offset = begin_offset;
+  int max_score = 0, max_score_offset = begin_offset, max_end_v = 0, max_end_h = 0;
   // Traverse all cigar
   char last_op = '\0';
-  int score = 0, op_length = 0;
+  int score = 0, end_v = 0, end_h = 0, op_length = 0;
   int i;
   for (i=begin_offset;i<end_offset;++i) {
     // Account for operation
-    if (operations[i] != last_op && last_op != '\0') {
-      score -= cigar_score_gap_affine2p_get_operations_score(last_op,op_length,penalties);
+    const char operation = operations[i];
+    if (operation != last_op && last_op != '\0') {
+      score -= cigar_maxtrim_gap_affine2p_score_op(last_op,op_length,penalties,&end_v,&end_h);
       op_length = 0;
+      // Compare max
+      if (max_score < score) {
+        max_score = score;
+        max_score_offset = i - 1;
+        max_end_v = end_v;
+        max_end_h = end_h;
+      }
     }
-    last_op = operations[i];
+    last_op = operation;
     ++op_length;
-    // Compare max
-    if (max_score < score) {
-      max_score = score;
-      max_score_offset = i;
-    }
   }
   // Account for last operation
-  score -= cigar_score_gap_affine2p_get_operations_score(last_op,op_length,penalties);
+  score -= cigar_maxtrim_gap_affine2p_score_op(last_op,op_length,penalties,&end_v,&end_h);
   if (max_score < score) {
     max_score = score;
-    max_score_offset = i;
+    max_score_offset = end_offset - 1;
+    max_end_v = end_v;
+    max_end_h = end_h;
   }
   // Keep the max-scoring part of the cigar
-  cigar->operations[max_score_offset+1] = '\0';
-  cigar->end_offset = max_score_offset + 1;
-  cigar->score = score;
+  const bool cigar_trimmed = (max_score_offset != end_offset-1);
+  if (max_score == 0) {
+    cigar_clear(cigar);
+  } else {
+    cigar->operations[max_score_offset+1] = '\0';
+    cigar->end_offset = max_score_offset + 1;
+    cigar->score = max_score;
+    cigar->end_v = max_end_v;
+    cigar->end_h = max_end_h;
+  }
+  // Return
+  return cigar_trimmed;
 }
 /*
  * Check
@@ -520,7 +633,7 @@ bool cigar_check_alignment(
         if (pattern[pattern_pos] != text[text_pos]) {
           if (verbose) {
             fprintf(stream,
-                "[AlignCheck] Alignment not matching (pattern[%d]=%c != text[%d]=%c)\n",
+                "[CIGAR] Alignment not matching (pattern[%d]=%c != text[%d]=%c)\n",
                 pattern_pos,pattern[pattern_pos],text_pos,text[text_pos]);
           }
           return false;
@@ -533,7 +646,7 @@ bool cigar_check_alignment(
         if (pattern[pattern_pos] == text[text_pos]) {
           if (verbose) {
             fprintf(stream,
-                "[AlignCheck] Alignment not mismatching (pattern[%d]=%c == text[%d]=%c)\n",
+                "[CIGAR] Alignment not mismatching (pattern[%d]=%c == text[%d]=%c)\n",
                 pattern_pos,pattern[pattern_pos],text_pos,text[text_pos]);
           }
           return false;
@@ -548,7 +661,7 @@ bool cigar_check_alignment(
         ++pattern_pos;
         break;
       default:
-        fprintf(stderr,"[AlignCheck] Unknown edit operation '%c'\n",operations[i]);
+        fprintf(stream,"[CIGAR] Unknown edit operation '%c'\n",operations[i]);
         exit(1);
         break;
     }
@@ -557,7 +670,7 @@ bool cigar_check_alignment(
   if (pattern_pos != pattern_length) {
     if (verbose) {
       fprintf(stream,
-          "[AlignCheck] Alignment incorrect length (pattern-aligned=%d,pattern-length=%d)\n",
+          "[CIGAR] Alignment incorrect length (pattern-aligned=%d,pattern-length=%d)\n",
           pattern_pos,pattern_length);
     }
     return false;
@@ -565,7 +678,7 @@ bool cigar_check_alignment(
   if (text_pos != text_length) {
     if (verbose) {
       fprintf(stream,
-          "[AlignCheck] Alignment incorrect length (text-aligned=%d,text-length=%d)\n",
+          "[CIGAR] Alignment incorrect length (text-aligned=%d,text-length=%d)\n",
           text_pos,text_length);
     }
     return false;
@@ -581,9 +694,9 @@ void cigar_print(
     cigar_t* const cigar,
     const bool print_matches) {
   // Check null
-  if (cigar->begin_offset >= cigar->end_offset) return;
+  if (cigar_is_null(cigar)) return;
   // Generate and print operations
-  char* const buffer = malloc(cigar->end_offset-cigar->begin_offset);
+  char* const buffer = malloc(2*(cigar->end_offset-cigar->begin_offset)+10);
   cigar_sprint(buffer,cigar,print_matches);
   fprintf(stream,"%s",buffer); // Print
   // Free
@@ -594,7 +707,7 @@ int cigar_sprint(
     cigar_t* const cigar,
     const bool print_matches) {
   // Check null
-  if (cigar->begin_offset >= cigar->end_offset) {
+  if (cigar_is_null(cigar)) {
     buffer[0] = '\0';
     return 0;
   }
@@ -629,9 +742,9 @@ void cigar_print_SAM_CIGAR(
     cigar_t* const cigar,
     const bool show_mismatches) {
   // Check null
-  if (cigar->begin_offset >= cigar->end_offset) return;
+  if (cigar_is_null(cigar)) return;
   // Generate and print operations
-  char* const buffer = malloc(cigar->end_offset-cigar->begin_offset);
+  char* const buffer = malloc(2*(cigar->end_offset-cigar->begin_offset));
   cigar_sprint_SAM_CIGAR(buffer,cigar,show_mismatches);
   fprintf(stream,"%s",buffer); // Print
   // Free
@@ -648,9 +761,15 @@ int cigar_sprint_SAM_CIGAR(
   // Print CIGAR-operations
   int i, cursor = 0;
   for (i=0;i<cigar_length;++i) {
-    cursor += sprintf(buffer+cursor,"%d%c",
-        cigar_buffer[i]>>4,
-        "MIDN---=X"[cigar_buffer[i]&0xf]);
+    const int op_idx = cigar_buffer[i] & 0xf;
+    if (op_idx <= 8) {
+      cursor += sprintf(buffer+cursor,"%d%c",
+          cigar_buffer[i]>>4,
+          "MIDN---=X"[cigar_buffer[i]&0xf]);
+    } else {
+      cursor += sprintf(buffer+cursor,"%d%c",
+          cigar_buffer[i]>>4,'?');
+    }
   }
   // Return
   buffer[cursor] = '\0';
@@ -663,20 +782,6 @@ void cigar_print_pretty(
     const int pattern_length,
     const char* const text,
     const int text_length) {
-  // Generate and print operations
-  char* const buffer = malloc(cigar->end_offset-cigar->begin_offset);
-  cigar_sprint_pretty(buffer,cigar,pattern,pattern_length,text,text_length);
-  fprintf(stream,"%s",buffer); // Print
-  // Free
-  free(buffer);
-}
-int cigar_sprint_pretty(
-    char* const buffer,
-    cigar_t* const cigar,
-    const char* const pattern,
-    const int pattern_length,
-    const char* const text,
-    const int text_length) {
   // Parameters
   char* const operations = cigar->operations;
   const int begin_offset = cigar->begin_offset;
@@ -741,20 +846,20 @@ int cigar_sprint_pretty(
     ++i;
   }
   // Print string
-  int cursor = 0;
-  cursor += sprintf(buffer,"      ALIGNMENT\t");
-  cursor += cigar_sprint(buffer+cursor,cigar,true);
-  cursor += sprintf(buffer+cursor,"\n");
-  cursor += sprintf(buffer+cursor,"      ALIGNMENT.COMPACT\t");
-  cursor += cigar_sprint(buffer+cursor,cigar,false);
-  cursor += sprintf(buffer+cursor,"\n");
-  cursor += sprintf(buffer+cursor,"      PATTERN    %s\n",pattern_alg);
-  cursor += sprintf(buffer+cursor,"                 %s\n",ops_alg);
-  cursor += sprintf(buffer+cursor,"      TEXT       %s\n",text_alg);
-  buffer[cursor] = '\0';
-  // Free & return
+  fprintf(stream,"      ALIGNMENT ");
+  cigar_print(stream,cigar,true);
+  fprintf(stream,"\n");
+  fprintf(stream,"      ETRACE    ");
+  cigar_print(stream,cigar,false);
+  fprintf(stream,"\n");
+  fprintf(stream,"      CIGAR     ");
+  cigar_print_SAM_CIGAR(stream,cigar,false);
+  fprintf(stream,"\n");
+  fprintf(stream,"      PATTERN    %s\n",pattern_alg);
+  fprintf(stream,"                 %s\n",ops_alg);
+  fprintf(stream,"      TEXT       %s\n",text_alg);
+  // Free
   free(mem);
-  return cursor;
 }
 
 
