@@ -17,11 +17,12 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ****/
 
 #pragma once
+#include <unordered_map>
 #include <limits>
 #include "daa_file.h"
 #include "../basic/packed_sequence.h"
 #include "../basic/value.h"
-#include "../basic/translate.h"
+#include "../util/sequence/translate.h"
 #include "../basic/packed_transcript.h"
 #include "../stats/score_matrix.h"
 #include "../basic/match.h"
@@ -48,6 +49,7 @@ struct DAA_query_record
 		{
 			return HspContext(*this,
 				(unsigned)parent_.query_num,
+				0,
 				parent_.query_seq,
 				parent_.query_name.c_str(),
 				subject_id,
@@ -58,13 +60,14 @@ struct DAA_query_record
 				Sequence());
 		}
 
+		void read(BinaryBuffer::Iterator &it);
+
 		uint32_t hsp_num, hit_num, subject_id, subject_len;
-		string subject_name;
+		std::string subject_name;
 
 	private:
 
 		const DAA_query_record &parent_;
-		friend BinaryBuffer::Iterator& operator>>(BinaryBuffer::Iterator &it, Match &r);
 
 	};
 
@@ -91,7 +94,7 @@ struct DAA_query_record
 		}
 		Match_iterator& operator++()
 		{
-			if (it_.good()) it_ >> r_; else good_ = false; return *this;
+			if (it_.good()) r_.read(it_); else good_ = false; return *this;
 		}
 	private:
 		Match r_;
@@ -110,6 +113,10 @@ struct DAA_query_record
 		return Match_iterator(*this, it_);
 	}
 
+	BinaryBuffer::Iterator raw_begin() const {
+		return it_;
+	}
+
 	size_t query_len() const
 	{
 		return align_mode.query_translated ? source_seq.size() : context[0].size();
@@ -128,8 +135,7 @@ private:
 	const DAA_file& file_;
 	const BinaryBuffer::Iterator it_;
 	
-	friend BinaryBuffer::Iterator& operator>>(BinaryBuffer::Iterator &it, Match &r);
-
 };
 
-BinaryBuffer::Iterator& operator>>(BinaryBuffer::Iterator &it, DAA_query_record::Match &r);
\ No newline at end of file
+
+void copy_match_record_raw(BinaryBuffer::Iterator& it, TextBuffer& buf, const std::unordered_map<uint32_t, uint32_t>& subject_map);
\ No newline at end of file
