@@ -217,7 +217,7 @@ void join_query(
 	const Search::Config &cfg)
 {
 	TranslatedSequence query_seq(cfg.query->translated(query));
-	Output::Info info = { cfg.query->seq_info(query), false, cfg.db.get(), out, {} };
+	Output::Info info = { cfg.query->seq_info(query), false, cfg.db.get(), out, {}, AccessionParsing() };
 	const double query_self_aln_score = flag_any(cfg.output_format->flags, Output::Flags::SELF_ALN_SCORES) ? cfg.query->self_aln_score(query) : 0.0;
 	BlockJoiner joiner(buf, *cfg.db, cfg.output_format.get());
 	vector<IntermediateRecord> target_hsp;
@@ -246,7 +246,9 @@ void join_query(
 			else {
 				const Loc tlen = cfg.db->dict_len(dict_id, block_idx);
 				const unsigned frame = i->frame(query_source_len, align_mode.mode);
-				Hsp hsp(*i, query_source_len, query_seq.index(frame).length(), tlen, cfg.output_format.get());
+
+                Hsp hsp = Hsp(*i, query_source_len, query_seq.index(frame).length(), tlen, cfg.output_format.get(), cfg.score_builder.get());
+
 				f.print_match(HspContext(hsp,
 					query,
 					cfg.query->block_id2oid(query),
@@ -295,7 +297,7 @@ void join_worker(TaskQueue<TextBuffer, JoinWriter> *queue, const Search::Config*
 
 			if (*cfg->output_format != OutputFormat::daa && config.report_unaligned != 0) {
 				for (unsigned i = fetcher.unaligned_from; i < fetcher.query_id; ++i) {
-					Output::Info info{ cfg->query->seq_info(i), true, cfg->db.get(), *out, {} };
+					Output::Info info{ cfg->query->seq_info(i), true, cfg->db.get(), *out, {}, AccessionParsing() };
 					cfg->output_format->print_query_intro(info);
 					cfg->output_format->print_query_epilog(info);
 				}
@@ -303,7 +305,7 @@ void join_worker(TaskQueue<TextBuffer, JoinWriter> *queue, const Search::Config*
 
 			unique_ptr<OutputFormat> f(cfg->output_format->clone());
 
-			Output::Info info{ cfg->query->seq_info(fetcher.query_id), false, cfg->db.get(), *out, {} };
+			Output::Info info{ cfg->query->seq_info(fetcher.query_id), false, cfg->db.get(), *out, {}, AccessionParsing() };
 			if (*f == OutputFormat::daa)
 				seek_pos = write_daa_query_record(*out, query_name, query_seq);
 			/*else if (config.global_ranking_targets)
@@ -364,7 +366,7 @@ void join_blocks(int64_t ref_blocks, Consumer &master_out, const PtrVector<TempF
 	if (*cfg.output_format != OutputFormat::daa && config.report_unaligned != 0) {
 		TextBuffer out;
 		for (BlockId i = JoinFetcher::query_last + 1; i < query_ids.size(); ++i) {
-			Output::Info info{ cfg.query->seq_info(i), true, cfg.db.get(), out, {} };
+			Output::Info info{ cfg.query->seq_info(i), true, cfg.db.get(), out, {}, AccessionParsing() };
 			cfg.output_format->print_query_intro(info);
 			cfg.output_format->print_query_epilog(info);
 		}
