@@ -34,16 +34,23 @@ void PAF_format::print_match(const HspContext& r, Output::Info& info)
 		<< r.query_source_range().begin_ << '\t'
 		<< r.query_source_range().end_ - 1 << '\t'
 		<< (Frame(r.frame()).strand == FORWARD ? '+' : '-') << '\t';
-
 	print_title(info.out, r.target_title.c_str(), false, false, "<>");
 
 	info.out << '\t' << r.subject_len << '\t'
 		<< r.subject_range().begin_ << '\t'
 		<< r.subject_range().end_ - 1 << '\t'
 		<< r.identities() << '\t'
-		<< r.length() << '\t'
-		<< "255" << '\t'
-		<< "AS:i:" << (uint32_t)score_matrix.bitscore(r.score()) << '\t'
+		<< r.length() << '\t';
+#ifdef WITH_DNA
+    if(config.command == ::Config::blastn){
+        info.out << r.mapping_quality() << '\t'
+        << "cm:i:" << r.n_anchors() << '\t';
+    } else
+        info.out << "255" << '\t';
+#else
+    info.out << "255" << '\t';
+#endif
+    info.out	<< "AS:i:" << (uint32_t)score_matrix.bitscore(r.score()) << '\t'
 		<< "ZR:i:" << r.score() << '\t'
 		<< "ZE:f:";
 	info.out.print_e(r.evalue());
