@@ -122,7 +122,7 @@ void Sam_format::print_match(const HspContext& r, Output::Info &info)
 	print_md(r, out);
 
 	if (config.sam_qlen_field)
-		out << '\t' << "ZQ:" << r.query.source().length();
+		out << '\t' << "ZQ:i:" << r.query.source().length();
 
 	out << '\n';
 }
