@@ -1,10 +1,7 @@
-#ifndef UTIL_IO_CONSUMER_H_
-#define UTIL_IO_CONSUMER_H_
+#pragma once
 
 struct Consumer {
 	virtual void consume(const char *ptr, size_t n) = 0;
 	virtual void finalize() {}
 	virtual ~Consumer() = default;
-};
-
-#endif
\ No newline at end of file
+};
\ No newline at end of file
