@@ -16,9 +16,7 @@ You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ****/
 
-#ifndef TEMP_FILE_H_
-#define TEMP_FILE_H_
-
+#pragma once
 #include <utility>
 #include "output_file.h"
 
@@ -41,6 +39,4 @@ private:
 	std::pair<std::string, int> init(bool unlink);
 #endif
 
-};
-
-#endif /* TEMP_FILE_H_ */
+};
\ No newline at end of file
