@@ -20,6 +20,10 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "simd.h"
 #include "util.h"
 
+#ifdef HAVE_GETAUXVAL
+#include <sys/auxv.h>
+#endif
+
 #ifdef _WIN32
 #define cpuid(info,x)    __cpuidex(info,x,0)
 #else
@@ -42,6 +46,21 @@ namespace SIMD {
 int flags = 0;
 
 Arch init_arch() {
+#if defined(__aarch64__) | defined(__arm__)
+
+#if defined(__aarch64__)
+	flags |= NEON;
+#elif defined(HAVE_MFPU_NEON) & defined(HAVE_GETAUXVAL)
+	unsigned long hwcaps = getauxval(AT_HWCAP);
+	if ((hwcaps & HWCAP_ARM_NEON) != 0)
+		flags |= NEON;
+#endif
+
+	if ((flags & NEON) != 0)
+		return Arch::NEON;
+
+#else
+
 #ifdef __SSE2__
 	int info[4];
 	cpuid(info, 0);
@@ -92,8 +111,8 @@ Arch init_arch() {
 		return Arch::AVX2;
 	if ((flags & SSSE3) && (flags & POPCNT) && (flags & SSE4_1))
 		return Arch::SSE4_1;
-	else
-		return Arch::Generic;
+#endif
+	return Arch::Generic;
 }
 
 Arch arch() {
@@ -104,6 +123,8 @@ Arch arch() {
 std::string features() {
 	init_arch();
 	std::vector<std::string> r;
+	if (flags & NEON)
+		r.push_back("neon");
 	if (flags & SSSE3)
 		r.push_back("ssse3");
 	if (flags & POPCNT)
@@ -115,4 +136,4 @@ std::string features() {
 	return r.empty() ? "None" : join(" ", r);
 }
 
-}
\ No newline at end of file
+}
