@@ -27,10 +27,12 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "vector8_avx512.h"
 #elif ARCH_ID == 2
 #include "vector8_avx2.h"
+#elif defined(__ARM_NEON)
+#include "vector8_neon.h"
 #elif defined(__SSE2__)
 #include "vector8_sse.h"
 #else
 #include "vector_generic.h"
 #endif
 
-#endif
\ No newline at end of file
+#endif
