@@ -12,7 +12,7 @@ using std::fixed;
 std::array<char, 16> fixed_string_seed;
 
 string convert_size(size_t size) {
-	static const char *SIZES[] = { "B", "KB", "MB", "GB" };
+	static const char *SIZES[] = { "B", "KB", "MB", "GB", "TB", "PB" };
 	size_t div = 0;
 	size_t rem = 0;
 
@@ -56,13 +56,33 @@ int64_t interpret_number(const std::string& s) {
 	char c = 0;
 	ss >> c;
 	if (ss.eof())
-		throw std::runtime_error("Missing size specifier in number: " + s + ". Permitted values: 'G'");
-	if (c != 'G')
-		throw std::runtime_error(string("Invalid size specifier (") + c + ") in number: " + s + ". Permitted values: 'G'");
+		throw std::runtime_error("Missing size specifier in number: " + s + ". Permitted values: T, G, M, K");
+	double mult = 1;
+	switch(c) {
+		case 'T':
+		case 't':
+			mult = 1e12;
+			break;
+		case 'G':
+		case 'g':
+			mult = 1e9;
+			break;
+		case 'M':
+		case 'm':
+			mult = 1e6;
+			break;
+		case 'K':
+		case 'k':
+			mult = 1e3;
+			break;
+		default:
+			throw std::runtime_error(string("Invalid size specifier (") + c + ") in number: " + s + ". Permitted suffixes: T, G, M, K");
+			break;
+	}
 	ss >> c;
 	if (!ss.eof())
 		throw std::runtime_error("Invalid number format: " + s);
-	return int64_t(n * 1e9);
+	return int64_t(n * mult);
 }
 
-}}
\ No newline at end of file
+}}
