@@ -79,14 +79,14 @@ size_t file_size(const char* name)
 
 void auto_append_extension(string &str, const char *ext)
 {
-	if (!ends_with(str, ext))
+	if (!str.empty() && !ends_with(str, ext))
 		str += ext;
 }
 
-void auto_append_extension_if_exists(string &str, const char *ext) {
-	if (!ends_with(str, ext))
-		if (exists(str + ext))
-			str += ext;
+string auto_append_extension_if_exists(const string &str, const char *ext) {
+	if (!ends_with(str, ext) && exists(str + ext))
+		return str + ext;
+	return str;
 }
 
 void log_rss() {
@@ -157,12 +157,9 @@ double total_ram() {
 #endif
 }
 
-#define handle_error(msg) \
-           do { perror(msg); exit(EXIT_FAILURE); } while (0)
-
 std::tuple<char*, size_t, int> mmap_file(const char* filename) {
 #ifdef WIN32
-	return { nullptr, 0, -1 };
+	throw std::runtime_error("Memory mapping not supported on Windows.");
 #else
 	void* addr;
 	int fd;
@@ -171,17 +168,17 @@ std::tuple<char*, size_t, int> mmap_file(const char* filename) {
 
 	fd = open(filename, O_RDONLY);
 	if (fd == -1)
-		return std::tuple<char*, size_t, int>(nullptr, 0, -1);
+		throw std::runtime_error(string("Error opening file: ") + filename);
 
-	if (fstat(fd, &sb) == -1)           /* To obtain file size */
-		handle_error("fstat");
+	if (fstat(fd, &sb) == -1)
+		throw std::runtime_error(string("Error calling fstat on file: ") + filename);
 
 	length = sb.st_size;
 
-	addr = mmap(NULL, length, PROT_READ,
-		MAP_SHARED, fd, 0);
+	addr = mmap(NULL, length, PROT_READ, MAP_SHARED, fd, 0);
 	if (addr == MAP_FAILED)
-		handle_error("mmap");
+		throw std::runtime_error(string("Error calling mmap on file: ") + filename);
+
 	return std::tuple<char*, size_t, int>((char*)addr, length, fd);
 #endif
 }
@@ -192,4 +189,13 @@ void unmap_file(char* ptr, size_t size, int fd) {
 	munmap((void*)ptr, size);
 	close(fd);
 #endif
+}
+
+size_t l3_cache_size() {
+#if defined(_MSC_VER) || defined(__APPLE__) || defined(__FreeBSD__) || (! defined(_SC_LEVEL3_CACHE_SIZE))
+	return 0;
+#else
+	const auto s = sysconf(_SC_LEVEL3_CACHE_SIZE);
+	return s == -1 ? 0 : s;
+#endif
 }
\ No newline at end of file
