@@ -18,15 +18,17 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 #include <algorithm>
 #include <numeric>
-#include <mutex>
 #include <iostream>
+#include <mutex>
 #include "../basic/config.h"
 #include "log_stream.h"
 #include "util.h"
 #include "escape_sequences.h"
 #include "profiler.h"
 
-using namespace std;
+using std::string;
+using std::vector;
+using std::endl;
 
 MessageStream message_stream;
 MessageStream verbose_stream (false);
@@ -163,7 +165,7 @@ std::string to_lower_case(const std::string& s)
 std::string print_char(char c)
 {
 	char buf[16];
-	if (c < 32)
+	if (c < 32 && c >= 0)
 		snprintf(buf, sizeof(buf), "ASCII %u", (unsigned)c);
 	else
 		snprintf(buf, sizeof(buf), "%c", c);
